require 'spec_helper'

describe BcryptHmac::Encryptor do
  let(:hmac_key) do
    'MzFjMzFlNGQ5MjQ3YmViZGYyOGI3NTkyYzA2YzE5NDQ1OWE2ZTMxYw=='
  end

  let(:bcrypt_cost) { '12' }

  let(:password) { 'super secret password' }

  let(:sha256_hmac_hashed_password) do
    OpenSSL::HMAC.digest(OpenSSL::Digest.new('sha256'), hmac_key, password)
  end

  let(:base64_encoded_hmac_hash) do
    Base64.encode64(sha256_hmac_hashed_password)
  end

  let(:bcrypt_hashed_password) do
    BCrypt::Password.create(base64_encoded_hmac_hash, cost: bcrypt_cost.to_i)
  end

  describe '::digest' do
    subject do
      BcryptHmac::Encryptor.digest(password, bcrypt_cost, nil, hmac_key)
    end

    it { is_expected.to eq(base64_encoded_hmac_hash) }
  end

  describe '::compare' do
    subject do
      BcryptHmac::Encryptor.compare(bcrypt_hashed_password, password,
                                    bcrypt_cost, nil, hmac_key)
    end

    it { is_expected.to be_truthy }
  end
end
